#! /usr/bin/env python

import sys

def usage(msg):
   sys.stderr.write("tag.py: %s\n" % msg)
   sys.stderr.write("Usage: tag.py [-a artist] [-l album] [-g genre] [-n track] [-t title] [-y year] [-c charset] filename\n")
   sys.exit(1)

from getopt import getopt, GetoptError
try:
   optlist, args = getopt(sys.argv[1:], "a:g:l:n:t:y:c:",
      ["artist=", "album=", "genre=", "track=", "title=", "year=", "charset="]
   )
except GetoptError:
   usage("iinvalid option")

artist = None
album = None
genre = None
track = None
title = None
year = None
charset = "ascii"

for _opt, _arg in optlist:
   if _opt in ("-a", "--artist"):
      artist = _arg
   elif _opt in ("-l", "--album"):
      album = _arg
   elif _opt in ("-g", "--genre"):
      from ID3 import ID3
      if _arg in ID3.genres:
         genre = _arg
      else:
         raise ValueError, "unknown genre `%s'" % _arg
   elif _opt in ("-n", "--track"):
      try:
         track = int(_arg)
      except ValueError:
         track = None
   elif _opt in ("-t", "--title"):
      title = _arg
   elif _opt in ("-y", "--year"):
      year = _arg
   elif _opt in ("-c", "--charset"):
      charset = _arg
try:
   del _opt, _arg
except NameError:
   pass

if args:
   if len(args) > 1:
      usage("too many arguments")

   filename = args[0]

else:
   usage("too few arguments")


from os import utime
from os.path import getmtime
mtime = getmtime(filename)

import ogg.vorbis
vf = ogg.vorbis.VorbisFile(filename)

tag = vf.comment()
tag.clear()

if album: tag.add_tag('ALBUM', album.decode(charset).encode('utf-8'))
if artist: tag.add_tag('ARTIST', artist.decode(charset).encode('utf-8'))
if track: tag.add_tag('TRACKNUMBER', str(track))
if title: tag.add_tag('TITLE', title.decode(charset).encode('utf-8'))
if genre: tag.add_tag('GENRE', genre)
if year: tag.add_tag('DATE', year)

tag.write_to(filename)
utime(filename, (mtime, mtime))
